@@ -151,7 +151,7 @@ static EContact *build_contact_from_entry (EBookBackendGAL *bl, LDAPMessage *e,
 
 static void manager_populate (EContact *contact, char **values, EBookBackendGAL *bl, E2kOperation *op);
 
-static void member_populate (EContact *contact, char **values);
+static void member_populate (EContact *contact, char **values, EBookBackendGAL *bl, E2kOperation *op);
 
 static void last_mod_time_populate (EContact *contact, char **values, EBookBackendGAL *bl, E2kOperation *op);
 
@@ -1235,7 +1235,7 @@ manager_populate(EContact *contact, char **values, EBookBackendGAL *bl, E2kOpera
 				str += len;
 
 static void
-member_populate (EContact *contact, char **values)
+member_populate (EContact *contact, char **values, EBookBackendGAL *bl, E2kOperation *op)
 {
 	int i;
 	gchar **member_info;
@@ -1326,7 +1326,7 @@ build_contact_from_entry (EBookBackendGAL *bl, LDAPMessage *e, GList **existing_
 	EContact *contact = e_contact_new ();
 	char *dn;
 	char *attr;
-	BerElement *ber = NULL, *tber = NULL;;
+	BerElement *ber = NULL, *tber = NULL;
 	gboolean is_group = FALSE;
 	
 	dn = ldap_get_dn(ldap, e);
@@ -1572,9 +1572,9 @@ ldap_search_handler (LDAPOp *op, LDAPMessage *res)
 	int msg_type;
 
 	d(printf ("ldap_search_handler (%p)\n", view));
-	printf("%s(%d):%s: search handler \n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+	printf("%s(%d):%s: search handler \n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 	if (!ldap) {
-		printf("%s(%d):%s: other error\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+		printf("%s(%d):%s: other error\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 		e_data_book_view_notify_complete (view, GNOME_Evolution_Addressbook_OtherError);
 		ldap_op_finished (op);
 		return;
@@ -1612,7 +1612,7 @@ ldap_search_handler (LDAPOp *op, LDAPMessage *res)
 				   NULL, &ldap_error_msg, NULL, NULL, 0);
 		g_mutex_unlock (bl->priv->ldap_lock);
 		if (ldap_error != LDAP_SUCCESS) {
-			printf("%s(%d):%s: error result\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+			printf("%s(%d):%s: error result\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 			g_warning ("ldap_search_handler: %02X (%s), additional info: %s",
 				   ldap_error,
 				   ldap_err2string (ldap_error), ldap_error_msg);
@@ -1627,7 +1627,7 @@ ldap_search_handler (LDAPOp *op, LDAPMessage *res)
 			e_data_book_view_notify_complete (view, GNOME_Evolution_Addressbook_Success);
 		else
 			e_data_book_view_notify_complete (view, GNOME_Evolution_Addressbook_OtherError);
-		printf("%s(%d):%s: o/p %d %d\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, ldap_error, LDAP_SUCCESS);
+		printf("%s(%d):%s: o/p %d %d\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION, ldap_error, LDAP_SUCCESS);
 		ldap_op_finished (op);
 	}
 	else {
@@ -1722,7 +1722,7 @@ start_book_view (EBookBackend  *backend,
 #if ENABLE_CACHE		
 		printf("Mode:Remote\n");
 		if (bl->priv->marked_for_offline && bl->priv->file_db) {
-			char *query = e_data_book_view_get_card_query (view);
+			const char *query = e_data_book_view_get_card_query (view);
 			GPtrArray *ids = NULL;
 			printf("Marked for offline and cache present\n");
 
@@ -1764,7 +1764,7 @@ start_book_view (EBookBackend  *backend,
 #endif			
 			printf("Not marked for offline or cache not there\n");
 			if (!bl->priv->ldap) {
-				printf("%s(%d):%s: no ldap :(\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+				printf("%s(%d):%s: no ldap :(\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 				e_data_book_view_notify_complete (view,
 								  GNOME_Evolution_Addressbook_InvalidQuery);
 				return;
@@ -1783,12 +1783,12 @@ start_book_view (EBookBackend  *backend,
 
 			status = build_query (bl, e_data_book_view_get_card_query (view),
 					      &ldap_query);
-			printf("%s(%d):%s: %s\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, ldap_query);
+			printf("%s(%d):%s: %s\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION, ldap_query);
 			if (status != GNOME_Evolution_Addressbook_Success || !ldap_query) {
 				e_data_book_view_notify_complete (view, status);
 				if (ldap_query)
 					g_free (ldap_query);
-				printf("%s(%d):%s: failure \n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+				printf("%s(%d):%s: failure \n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 				return;
 			}
 
@@ -1796,7 +1796,7 @@ start_book_view (EBookBackend  *backend,
 				book_view_notify_status (view, _("Searching..."));
 
 				g_mutex_lock (bl->priv->ldap_lock);
-				printf("%s(%d):%s: starting \n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+				printf("%s(%d):%s: starting \n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 				ldap_err = ldap_search_ext (bl->priv->ldap, LDAP_ROOT_DSE,
 							    LDAP_SCOPE_SUBTREE,
 							    ldap_query,
@@ -1807,18 +1807,18 @@ start_book_view (EBookBackend  *backend,
 							    view_limit,
 							    &search_msgid);
 				g_mutex_unlock (bl->priv->ldap_lock);
-				printf("%s(%d):%s: %d\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, ldap_err);
+				printf("%s(%d):%s: %d\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION, ldap_err);
 			} while (gal_reconnect (bl, view, ldap_err));
 
 			g_free (ldap_query);
 
 			if (ldap_err != LDAP_SUCCESS) {
-				printf("%s(%d):%s: error\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+				printf("%s(%d):%s: error\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 				book_view_notify_status (view, ldap_err2string(ldap_err));
 				return;
 			}
 			else if (search_msgid == -1) {
-				printf("%s(%d):%s: error\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+				printf("%s(%d):%s: error\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 				book_view_notify_status (view,
 							 _("Error performing search"));
 				return;
@@ -1827,7 +1827,7 @@ start_book_view (EBookBackend  *backend,
 				LDAPSearchOp *op = g_new0 (LDAPSearchOp, 1);
 
 				d(printf ("adding search_op (%p, %d)\n", view, search_msgid));
-				printf("%s(%d):%s: adding search \n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+				printf("%s(%d):%s: adding search \n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 				op->view = view;
 
 				bonobo_object_ref (view);
@@ -1897,7 +1897,7 @@ tool_server_controls( LDAP *ld, LDAPControl *extra_c, int count )
 
 	err = ldap_set_option( ld, LDAP_OPT_SERVER_CONTROLS, ctrls );
 
-	if ( err != LDAP_OPT_SUCCESS ) {
+	if ( err != LDAP_SUCCESS ) {
 		for ( j = 0; j < i; j++ ) {
 			if ( ctrls[j]->ldctl_iscritical ) crit = 1;
 		}
@@ -1911,6 +1911,26 @@ tool_server_controls( LDAP *ld, LDAPControl *extra_c, int count )
 	}
 }
 
+#ifdef SUNLDAP
+static struct berval *
+ber_dupbv( struct berval *dst, struct berval *src )
+{
+	struct berval *tmp;
+
+	tmp = ber_bvdup(src);
+	if (!tmp)
+		return NULL;
+
+	dst->bv_len = tmp->bv_len;
+	dst->bv_val = tmp->bv_val;
+	tmp->bv_len = 0;
+	tmp->bv_val = NULL;
+	ber_bvfree (tmp);
+
+	return dst;
+}
+#endif
+
 static int 
 parse_page_control(
 	LDAP *ld,
@@ -2168,7 +2188,7 @@ authenticate_user (EBookBackend *backend,
 		if (!exchange_account_get_context (account)) {
 			exchange_account_set_online (account);
 			if(!exchange_account_connect (account, password, &result)) {
-				printf("%s(%d):%s: failed\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+				printf("%s(%d):%s: failed\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 				e_data_book_respond_authenticate_user (book, opid, GNOME_Evolution_Addressbook_AuthenticationFailed);
 				return;
 			}
@@ -2182,11 +2202,11 @@ authenticate_user (EBookBackend *backend,
 #if ENABLE_CACHE		
 		if (be->priv->marked_for_offline) {
 			if (e_book_backend_db_cache_is_populated (be->priv->file_db) ) {
-				printf("Cache is populated, check if refresh is required \n");
 				time_t t1, t2;
 				int diff;
 
 				char *t = e_book_backend_db_cache_get_time (be->priv->file_db);
+				printf("Cache is populated, check if refresh is required \n");
 				if (t && *t)
 					t1 = atoi (t);
 				else
@@ -2222,6 +2242,25 @@ authenticate_user (EBookBackend *backend,
 	return;
 }
 
+#ifdef SUNLDAP
+static int
+ber_flatten2( BerElement *ber, struct berval *bv, int alloc )
+{
+	struct berval *tmp;
+
+	if ( ber_flatten( ber, &tmp) == -1 ) {
+		return;
+	}
+	bv->bv_len = tmp->bv_len;
+	bv->bv_val = tmp->bv_val;
+	tmp->bv_len = 0;
+	tmp->bv_val = NULL;
+	ber_bvfree (tmp);
+
+	return 0;
+}		
+#endif
+
 static void
 ldap_cancel_op(void *key, void *value, void *data)
 {
@@ -2319,7 +2358,7 @@ get_supported_auth_methods (EBookBackend *backend,
 			    guint32       opid)
 
 {
-	printf("%s(%d):%s: NONE\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+	printf("%s(%d):%s: NONE\n", __FILE__, __LINE__, G_GNUC_PRETTY_FUNCTION);
 	e_data_book_respond_get_supported_auth_methods (book,
 							opid,
 							GNOME_Evolution_Addressbook_Success,
@@ -2471,7 +2510,7 @@ load_source (EBookBackend *backend,
  			int rv;
  
  			/* the database didn't exist, so we create the directory then the .db */
- 			rv= e_util_mkdir_hier (dirname, 0777);
+ 			rv= g_mkdir_with_parents (dirname, 0777);
  			if (rv == -1 && errno != EEXIST) {
  				g_warning ("failed to make directory %s: %s", dirname, strerror (errno));
  				g_free (dirname);
